fa = {
    "author": "Amir Shokri",
    "email": "amirsh.nll@gmail.com",
    "update_time": "4 July, 2021",
    "source ": "https://github.com/amirshnll/Persian-Swear-Words",
    "word": [
        "آبکیر",
        "آشغال",
        "آلتتناسلی",
        "آلت",
        "ابله",
        "ابنیزید",
        "احمق",
        "اسب",
        "اسبی",
        "اسکل",
        "اسکل",
        "اسگل",
        "اسگول",
        "الاغ",
        "الاق",
        "انگل",
        "انی",
        "انی",
        "اوسکل",
        "اوسکل",
        "اوسگل",
        "اوصکل",
        "اوصگل",
        "بک",
        "باسن",
        "بخورش",
        "بدبخت",
        "بمال",
        "بهتخمم",
        "بهچپم",
        "بهکیرم",
        "بپرروش",
        "بپرسرش",
        "بچهکونی",
        "بکارت",
        "بکنبکن",
        "بکنتوش",
        "بکن",
        "بکنش",
        "بکنمت",
        "بیآبرو",
        "بیخایه",
        "بیشرف",
        "بیشعور",
        "بیعفت",
        "بیغیرت",
        "بیناموس",
        "بیناموس",
        "بیپدر",
        "بیابخورش",
        "بیشعور",
        "بیناموس",
        "تخمسگ",
        "تخمی",
        "ترک",
        "تولهسگ",
        "جاکش",
        "جاکش",
        "جاکش",
        "جلقزدن",
        "جندهخانه",
        "جنده",
        "جنسی",
        "جون",
        "جکس",
        "جیندا",
        "حرومزاده",
        "حشر",
        "حشریشدن",
        "حشری",
        "حیوانی",
        "خارکسده",
        "خارکسده",
        "خارکسده",
        "خارکسّه",
        "خانمجنده",
        "خایهخور",
        "خایهمال",
        "خایه",
        "خر",
        "خرفت",
        "خری",
        "خز",
        "خفهخون",
        "خفهشو",
        "خفه",
        "خنگ",
        "خواهرجنده",
        "خیکاس",
        "دافناز",
        "داف",
        "داگاستایل",
        "دخترجنده",
        "دخترقرتی",
        "درازگوش",
        "دله",
        "دهنسرویس",
        "دهنگاییده",
        "دهنتسرویس",
        "دهنتوببند",
        "دوجنسه",
        "دوستدختر",
        "دوستپسر",
        "دول",
        "دکل",
        "دیوث",
        "دیوس",
        "دیوسخان",
        "دیوص",
        "رشتی",
        "ریدن",
        "ریدی",
        "زارت",
        "زباله",
        "زرنزن",
        "زنجنده",
        "زنجنده",
        "زنکاسده",
        "زنازاده",
        "زنا",
        "زنازاده",
        "زنتو",
        "زنشو",
        "زنیکه",
        "سادیسمی",
        "ساکبزن",
        "ساک",
        "ساکونی",
        "سرخور",
        "سرکیر",
        "سسکی",
        "سوراخکون",
        "سولاخ",
        "سکسچت",
        "سکس",
        "سکسیباش",
        "سکسی",
        "سکسیم",
        "سکسیی",
        "سگتوروحت",
        "سگدهن",
        "سگصفت",
        "سگپدر",
        "سگی",
        "سیکتیر",
        "شاسگول",
        "شاش",
        "شقکردن",
        "شلمغز",
        "شنگول",
        "شهوتی",
        "شورتمماسکت",
        "صیغهای",
        "صیک",
        "عرب",
        "عرقخور",
        "عمتو",
        "عمهننه",
        "عنتر",
        "عن",
        "عن",
        "عنتر",
        "عوضی",
        "غرمساق",
        "غرمصاق",
        "قرمساق",
        "قرمصاق",
        "فاحشهخانم",
        "فاحشه",
        "فارس",
        "فاکفیس",
        "فیلمسوپر",
        "قرتی",
        "قرمساق",
        "قرمصاق",
        "قس",
        "لاپا",
        "لاس",
        "لاشگوشت",
        "لاشی",
        "لاشی",
        "لامصب",
        "لاکونی",
        "لجن",
        "لخت",
        "لختی",
        "لز",
        "مادرجنده",
        "مادرسگ",
        "مادرقهوه",
        "مادرکونی",
        "مالوندن",
        "ماچ کردنی",
        "ماچ",
        "مرتیکه",
        "مردیکه",
        "مرضداری",
        "مرضداری",
        "مشروب",
        "ملنگ",
        "ممهخور",
        "ممه",
        "منگل",
        "میخوریش",
        "نرکده",
        "نعشه",
        "نکبت",
        "نگاییدم",
        "هیز",
        "ولدزنا",
        "پدرسوخته",
        "پدرسگ",
        "پدرصلواتی",
        "پدرسگ",
        "پریود",
        "پستان",
        "پسون",
        "پشمام",
        "پفیوز",
        "پلشت",
        "پورن",
        "پپه",
        "چاغال",
        "چاقال",
        "چسخور",
        "چس",
        "کاسکش",
        "کثلیس",
        "کث",
        "کثافت",
        "کثافط",
        "کردن",
        "کردنی",
        "کرم",
        "کسخل",
        "کسخور",
        "کسخیس",
        "کسدادن",
        "کسلیس",
        "کسلیس",
        "کسلیسیدن",
        "کسننت",
        "کسوکیر",
        "کسکردن",
        "کسکش",
        "کس",
        "کسخل",
        "کسشعر",
        "کسکش",
        "کسکیر",
        "کصخل",
        "کصلیس",
        "کص",
        "کصافت",
        "کصافط",
        "کصخل",
        "کصکش",
        "کلفت",
        "کلهکیری",
        "کلهکیری",
        "کوثلیس",
        "کوسخل",
        "کوسخور",
        "کوسلیس",
        "کوس",
        "کوصخل",
        "کوصلیس",
        "کوص",
        "کونتپل",
        "کونده",
        "کونسوراخ",
        "کونپنیر",
        "کونگنده",
        "کون",
        "کوندهخار",
        "کوندهخوار",
        "کونده",
        "کونشو",
        "کونن",
        "کونی",
        "کونی",
        "کیر",
        "کیردراز",
        "کیردوس",
        "کیرر",
        "کیرمکیدن",
        "کیرناز",
        "کیروکس",
        "کیروکس",
        "کیری",
        "گاو",
        "گاوی",
        "گاگول",
        "گایدن",
        "گایدی",
        "گاییدن",
        "گردندراز",
        "گشاد",
        "گندهگوز",
        "گه",
        "گهی",
        "گوزباقالي",
        "گوز",
        "گوزو",
        "گوزو",
        "گوسفند",
        "گوشدراز",
        "گوه",
        "گوه",
        "گیزن",
        "گیخوار",
        "یبنزنا",
        "مادرتو",
        "ناموستو",
        "چنده",
        "باسنی",
        "جندهپولی",
        "ساعتی چند",
        "کصناموس",
        "خارکصده",
        "سیکیم",
        "سگناموس",
        "نوب",
        "خایمال",
        "مادربهخطا",
        "کصلیس",
        "بکنت",
        "کصده",
        "گورومساخ",
        "پوفیوز",
        "پدرتو",
        "قورومساق",
        "سیهدیر",
        "اوبی",
        "مادرسگ",
        "نگایدم",
        "کصمغز",
        "موز",
    ],
}
